.. _router_module:

:mod:`pyramid.router`
---------------------

.. automodule:: pyramid.router

.. autofunction:: pyramid.router.make_app(root_factory, package=None, filename='configure.zcml', settings=None)
